@@ -101,7 +101,7 @@ class InstanceSettings:
                 # this seems to work even if there is an open connection
                 # to the cache file
                 os.utime(cache_file, times=(cloud_mtime, cloud_mtime))
-            locker = self._locker
+            locker = self.locker
             if locker is not None:
                 locker.unlock()
 
@@ -129,13 +129,17 @@ class InstanceSettings:
         """Database engine."""
         return self._engine
 
+    @property
+    def locker(self):
+        if self.dialect == "sqlite" and self._locker is None:
+            self._locker = get_locker()
+
+        return self._locker
+
     def session(self, lock: bool = False) -> sqm.Session:
         """Database session."""
         if lock:
-            if self.dialect == "sqlite" and self._locker is None:
-                self._locker = get_locker()
-
-            locker = self._locker
+            locker = self.locker
             if locker is not None:
                 try:
                     locker.lock()
@@ -143,6 +147,26 @@ class InstanceSettings:
                     locker.unlock()
                     raise e
 
+        if self.dialect == "sqlite" and self.storage.is_cloud:
+            sqlite_file = self._sqlite_file
+            cache_file = self.storage.cloud_to_local_no_update(sqlite_file)
+            # checking cloud mtime several times here because of potential changes
+            # during the synchronizization process. Maybe better
+            # to make these checks dependent on lock,
+            # i.e. if locked check cloud mtime only once.
+            if not cache_file.exists():
+                cache_file.parent.mkdir(parents=True, exist_ok=True)
+                cloud_mtime = sqlite_file.stat().st_mtime  # type: ignore
+                sqlite_file.download_to(cache_file)  # type: ignore
+                os.utime(cache_file, times=(cloud_mtime, cloud_mtime))
+            elif sqlite_file.stat().st_mtime > cache_file.stat().st_mtime:  # type: ignore  # noqa
+                # checking the time again because
+                # it could be changed in the meantime
+                # maybe remove this checks when locked
+                cloud_mtime = sqlite_file.stat().st_mtime  # type: ignore
+                sqlite_file.download_to(cache_file)  # type: ignore
+                os.utime(cache_file, times=(cloud_mtime, cloud_mtime))
+
         return sqm.Session(self.engine, expire_on_commit=False)
 
     @property
@@ -174,6 +198,9 @@ class InstanceSettings:
 
     def _persist(self) -> None:
         assert self.name is not None
+        if self.storage.type == "local":
+            self.storage.root.mkdir(parents=True, exist_ok=True)
+
         filepath = instance_settings_file(self.name, self.owner)
         # persist under filepath for later reference
         save_instance_settings(self, filepath)
